'use strict';

module.exports = function (grunt) {

	require('load-grunt-tasks')(grunt);

	// Time how long tasks take. Can help when optimizing build times
	require('time-grunt')(grunt);

	// Define the configuration for all the tasks
	grunt.initConfig({
		pkg: require('./package.json'),

		// Project settings
		yeoman: {
		  	// configurable paths
		 	app: require('./bower.json').appPath || 'app',
			dist: 'dist'
		},
		replace: {
			resource: {
				options: {
					patterns: [
						{
							match: /\{baseUrl\}/g,
							replacement: '<%= replace.baseUrl %>'
						}
					]
				},
				files: [
					{expand: true, flatten: true, src: ['app/resource-directory.json'], dest: 'dist'}
				]
			}
		}
	});


	// load per-task config from separate files found in grunt directory
	grunt.loadTasks('grunt');

	grunt.registerTask('serve', function (target) {
		if (target === 'dist') {
		  return grunt.task.run(['build:dev', 'connect:dist:keepalive']);
		}

		grunt.task.run([
		  'clean:server',
		  'concurrent:server',
		  'autoprefixer',
		  'connect:livereload',
		  'watch'
		]);
	});
	grunt.registerTask('replace-resource', "replace resource's baseUrl", function() {
		grunt.config.set('replace.baseUrl', grunt.option('baseUrl'));
		grunt.task.run('replace:resource');
	});

	grunt.registerTask('pick-platform', "choose platform", function() {
		grunt.config.set('platform', "-" + grunt.option('platform'));
		if (grunt.config.get('platform') != "-android" && grunt.config.get('platform') != "-ios") {
			grunt.config.set('platform', "");
		}
		var command = 'cp app/index'+grunt.config.get('platform')+'.html dist/index.html';
		require('shelljs').exec(command);
	});

	grunt.registerTask('server', function (target) {
		grunt.log.warn('The `server` task has been deprecated. Use `grunt serve` to start a server.');
		grunt.task.run(['serve:' + target]);
	});

	grunt.registerTask('test', [
		'clean:server',
		'clean:coverage',
		'concurrent:test',
		'autoprefixer',
		'connect:test',
		'karma'
	]);

	grunt.registerTask('build:dev', [
		'clean:dist',
		'useminPrepare',
		'concurrent:dist',
		'autoprefixer',
		'concat',
		'shell:version',
		'ngtemplates:dev',
		'copy:dev',
		'targethtml:dev',
		'cdnify',
		'cssmin:generated',
		'uglify:generated',
		'usemin',
		'replace-resource',
		'pick-platform'
	]);

	grunt.registerTask('build:dist', [
		'clean:dist',
		'useminPrepare',
		'concurrent:dist',
		'autoprefixer',
		'concat',
		'shell:version',
		'copy:dist',
		'targethtml:dist',
		'cdnify',
		'cssmin:generated',
		'uglify:generated',
		'usemin',
		'ngtemplates:dist',
		'requirejs',
		'replace-resource',
        'pick-platform'
	]);

	grunt.registerTask('default', [
		'newer:jshint',
		'test',
		'build'
	]);

    grunt.registerTask('version', [
		'shell:version'
	]);

	grunt.registerTask('bowerCopy', [
		'bower-linker:dev'
	]);
};
