require 'rubygems'
require 'rspec'

require 'page-object'
require 'json'

require_relative '../../../lib/helper/common_element'
require_relative '../../../lib/helper/accordion_helper'

class Assess < AccordionHelper
	include PageObject

	span(:firstPageContent, :css => 'div.primary-content div:nth-of-type(2) span')
	elements(:assessMenuList, :li, :css => '.secondary-list li')
	button(:takeAssessmentBtn, :css => '.take-assessment')
	button(:graphPastResultsBtn, :css => '.past-results')
	# take assessment
	button(:beginBtn, :css => '.questionnaire-start')
	h4(:takeAssessmentHeader, :css => 'div.primary-content .page h4')
	p(:takeAssessmentContent, :css => 'div.primary-content .page p')

	button(:backBtn, :css => '.questionnaire-back')
	button(:nextBtn, :css => '.questionnaire-next')
	button(:saveBtn, :css => '.questionnaire-save')

	#button(:backBtn, :css => 'button[ng-click="navAction("BACK")"]')

	radio_button(:never, :css => '.input-group-radio div:nth-of-type(1) input')
	radio_button(:rarely, :css => '.input-group-radio div:nth-of-type(2) input')
	radio_button(:sometimes, :css => '.input-group-radio div:nth-of-type(3) input')
	radio_button(:quite_frequently, :css => '.input-group-radio div:nth-of-type(4) input')
	radio_button(:nearly_always, :css => '.input-group-radio div:nth-of-type(5) input')

	radio_button_group(:answer,  :name => "Q2-option")

	h3(:save_confirmation_modal, :css => '.modal-content h3')
	p(:draft_saved, :css => '.modal-body p')
	button(:ok_confirmation, :css => 'div[ng-if="!okButtonFirst"] button')
	h5(:questionNumberHeading, :id => 'question-number')

	h3(:submissionConfirmation, :css => '.modal-header h3')
	button(:submissionReturn, :css => 'button[data-ng-click="modalContent.close()"]')
	button(:submissionContinue, :css => 'button[data-ng-click="modalContent.ok();"]')


	button(:assessmentReportPrint, :css => 'button[ng-click="printResults()"]')
	h2(:assessmentReportHeader, :css=> '.primary-header h2')

	p(:paragraph1, :css => 'div.primary-content div div.page span.at p:nth-of-type(1)')
	p(:paragraph2, :css => 'div.primary-content div div.page span.at p:nth-of-type(2)')
	p(:paragraph3, :css => '.at p:nth-of-type(3)')
	p(:paragraph4, :css => '.at p:nth-of-type(4)')
	p(:paragraph5, :css => '.at p:last-child')

	p(:reminderText, :css => 'div.primary-content div div.page span.at + p')
	button(:setReminder, :id => 'setup-assessment-notification')

	h4(:assessmentTitle, :css => 'div.assessment-preview div:nth-of-type(2) h4')
	p(:assessmentPatient, :css => 'div.assessment-preview div:nth-of-type(2) h4 + p')

	elements(:reportQuestionAnswer, :li, :css => '.assessment-preview > div >  div > ol > li')

	div(:reassessment, :css => '.primary-header +div')




	def getQuestionList
		return [
			"* Indicate how often you have felt the following in the past week: Because of the time you spend with your Veteran, you don't have enough time for yourself.",
			"* Indicate how often you have felt the following in the past week: Stressed between caring for your Veteran and trying to meet other responsibilities (work/family).",
			"* Indicate how often you have felt the following in the past week: Angry when you are around your Veteran.",
			"* Indicate how often you have felt the following in the past week: Your Veteran currently affects your relationship with family members or friends in a negative way.",
			"* Indicate how often you have felt the following in the past week: Strained when you are around your Veteran.",
			"* Indicate how often you have felt the following in the past week: Your health has suffered because of your involvement in caring for your Veteran.",
			"* Indicate how often you have felt the following in the past week: You don't have as much privacy as you would like because of your Veteran.",
			"* Indicate how often you have felt the following in the past week: Your social life has suffered because you are caring for your Veteran.",
			"* Indicate how often you have felt the following in the past week: You have lost control of your life since your Veteran's illness.",
			"* Indicate how often you have felt the following in the past week: Uncertain about what to do about your Veteran.",
			"* Indicate how often you have felt the following in the past week: You should be doing more for your Veteran.",
			"* Indicate how often you have felt the following in the past week: You could do a better job in caring for your Veteran."
		]
	end

	def getParagraphReportList
		return [
			"You have successfully submitted the Zarit Caregiver Assessment for zztest patient01.",
			"Your score indicates that",
			"Based upon your answers, the tools and education items listed below are the ones that are most likely to help you. These recommended tool categories will be highlighted on the Manage section of this application until the next time you take this assessment.",
			"Visit the Support section of the App
			Relax Yourself
			Change Perspective
			Plan a Social Activity
			Pleasant Events
			Distract Yourself
			Soothe Yourself
			Take a Time Out",
			"A copy of the questions and your responses is provided below. This page may be printed using your browser print function."

		]
	end

	def getQuestionText(num)
		questionText =  @browser.span(:css => "[name=\"Q" + num.to_s + "\"] .input-group-radio-legend")
		return questionText.text.strip()
	end

	def getNthAssessItem(number)
		return assessMenuList_elements[number - 1].text()
	end

	def getReportQuestion(listNumber)
		return reportQuestionAnswer_elements[listNumber].text().split('.')[0].strip()
	end

	def getReportAnswer(listNumber)
		return reportQuestionAnswer_elements[listNumber].text().split('.')[1].strip()
	end

	def generateRandomSelection()
		#return rand(answer_elements.length)
		return rand(5)
	end


end