require 'rspec'
require 'watir-webdriver'

require_relative '../../lib/browser_container/site'
require_relative '../rspec_helper'

describe '[About]', :acceptance => true do

  app_title = "Care4Caregivers"

  before(:all) do
    @driver = Watir::Browser.new
    @site = Site.new(BASE_URL, @driver)

    @login = @site.loginPage
    @eula = @site.eula
    @roa = @site.roa
    @landing = @site.landing
    @lp = @site.launchpad
    @rightNav = @site.rightMenu
    @modal = @site.modal
    @about = @site.about

  end

  after(:all) do
    @site.quitDriver
  end

  context "About Selection" do
    it ". When a user selects About from the User Menu, the system displays the About information in a modal screen" do
      acceptEulaAndQuickLogin("zztest.patient01", "pass", "D123401")

      expect(@landing.appTitle).to eq(app_title)
      @landing.welcomeTitleForAuthenticatedUser_element.when_visible
      expect(@landing.welcomeTitleForAuthenticatedUser).to eq("Welcome to Care4Caregivers")

      @rightNav.rightMenu_element.when_visible

      @rightNav.rightMenu
      @rightNav.menuHeader_element.when_visible

      @rightNav.about_element.when_visible
      @rightNav.about

      @about.title_element.when_visible
      expect(@about.title_element.text).to eq("About")
      expect(@about.version_element.text).to eq("Care4Caregivers - v1.0.0")

    end
  end


  context "EULA link" do
    it ". Link Label: EULA" do
      expect(@about.eula_element.text).to eq("End User License Agreement (EULA)")
    end

    it ". Selecting the EULA opens the EULA in a new window" do
      @about.eula
      @site.switchWindowToLast

      Watir::Wait.until {@eula.eulaTitle_element.text == "End User License Agreement"}
      @eula.eulaTitle_element.when_visible
      expect(@eula.eulaTitle_element.text).to eq("End User License Agreement")

      @site.closeBrowser

      @site.switchWindowToFirst
    end
  end

  context "OK Button for About" do
    it ". OK button" do
      expect(@about.ok_element.text).to eq("OK")
    end

    it ". Selecting the OK button closes the modal and returns the user focus to the About menu button" do
      @about.ok
      Watir::Wait.until {@about.isAboutPopUpPresent == false}
      expect(@about.isAboutPopUpPresent).to eq(false)

      Watir::Wait.until {@rightNav.isAboutFocused}
      expect(@rightNav.isAboutFocused).to eq(true)
    end

  end

end
