require 'rspec'
require 'watir-webdriver'
require_relative '../rspec_helper'
require_relative '../../lib/browser_container/site'

describe '[ EULA]
          [ ROA]', :acceptance => true do
  include DBUtility

  app_title = "Care4Caregivers"

  before(:all) do
    @driver = Watir::Browser.new
    @site = Site.new(BASE_URL, @driver)

    # remove entry from Right Of Access table to trigger ROA show up
    deleteUserFromRightOfAccess("D123401")

    @loginPage = @site.loginPage
    @eula = @site.eula
    @roa = @site.roa
    @landing = @site.landing
    @lp = @site.launchpad
    @rightNav = @site.rightMenu


  end
  
  after(:all) do
    @site.quitDriver
  end

  context 'AC #CFC-90: Display of EULA for Care for Caregiver app' do
    it '. Each time the user opens the app using a new device/browser combination, the system displays the current EULA' do
      Watir::Wait.until {@eula.accept_element.exists?}
      @eula.eulaTitle_element.when_visible
    end

    it '. Header: End User License Agreement ' do
      expect(@eula.eulaTitle).to eq("End User License Agreement")
    end

    it '. Decline a Eula returns to LaunchPad ' do
      @eula.decline_element.when_visible
      expect(@eula.decline_element.text).to eq("Decline")
      @eula.decline

      @lp.appTitle_element.when_visible
      expect(@lp.appTitle).to eq("Launchpad")

      @lp.care4caregivers_element.when_visible
      @lp.care4caregivers

      @eula.eulaTitle_element.when_visible
      expect(@eula.eulaTitle).to eq("End User License Agreement")
    end

    it '. Accept a Eula lands user on the landing screen' do
      @eula.accept_element.when_visible
      expect(@eula.accept_element.text).to eq("Accept")
      @eula.accept
      @landing.appTitle_element.when_visible
      expect(@landing.appTitle).to eq(app_title)
    end

    it '. Verify that after user accepts a EULA, it will not show up again' do
      @site.goto(BASE_URL)
      puts "eula shall not show up"
      @landing.appTitle_element.when_visible
      expect(@landing.appTitle).to eq(app_title)
    end

  end

  context 'Display of ROA for Care4Caregiver app' do
    it '. When a user authenticates into the app, if the user has not signed the current ROA, the system presents the current ROA for acceptance.' do
      @rightNav.rightMenu
      Watir::Wait.until {@rightNav.login?}
      @rightNav.login
      @loginPage.login_without_passing_ROA("zztest.patient01", "pass")
      @roa.nextButton_element.when_visible
      expect(@roa.appTitle).to eq("Right Of Access")
    end

    it '. Header: Right of Access' do
      expect(@roa.appTitle).to eq("Right Of Access")
    end

    it '. When Cancel button is selected, user is return to the Launchpad.' do
      @roa.firstCancel_element.when_visible
      expect(@roa.firstCancel_element.exists?).to eq(true)
      expect(@roa.nextButton_element.exists?).to eq(true)

      expect(@roa.firstCancel_element.text).to eq("Cancel")
      @roa.firstCancel
      Watir::Wait.until {@site.getCurrentURL().include?(LP_URL)}
      expect(@site.getCurrentURL().include?(LP_URL)).to eq(true)

	  if (@lp.lpAccept?)
		  @lp.lpAccept_element.when_visible
		  @lp.lpAccept
		  Watir::Wait.until {@site.getCurrentURL().include?(LP_URL)}
		  expect(@site.getCurrentURL().include?(LP_URL)).to eq(true)
	  end


      @lp.care4caregivers_element.when_visible
      @lp.care4caregivers

    end


    it '. When Next button is selected, the ROA for is presented and when Cancel button is selected, user is returned to the previous screen' do
      @roa.nextButton_element.when_visible
      @roa.nextButton

      Watir::Wait.until { @roa.secondCancel? }
      @roa.secondCancel_element.when_visible
      @roa.secondCancel
      @roa.nextButton_element.when_visible
      expect(@roa.appTitle).to eq("Right Of Access")
    end

    it '. When user clicks through next and verify, user logs in successfully' do
      @roa.nextButton
      Watir::Wait.until {@roa.verify?}
      @roa.verify_element.when_visible
      @roa.verify
      Watir::Wait.until { @loginPage.loginAs? }

      expect(@loginPage.loginAs).to eq("Logged in as patient01, zztest")
    end

    it '. When logout and logback in again, ROA shall not present' do
      @rightNav.rightMenu_element.when_visible
      @rightNav.rightMenu
      Watir::Wait.until {@rightNav.logout?}
      @rightNav.logout_element.when_visible
      @rightNav.logout

      Watir::Wait.until { @lp.launchpadHeader_element.text == "Launchpad"}
      expect(@lp.launchpadHeader_element.text).to eq("Launchpad")

      @lp.care4caregivers_element.when_visible
      @lp.care4caregivers

      Watir::Wait.until { @landing.appTitle_element.exists? }
      @landing.appTitle_element.when_visible
      expect(@landing.appTitle).to eq(app_title)

	end

  end
end
