require 'rspec'
require 'watir-webdriver'

require_relative '../../lib/browser_container/site'
require_relative '../../lib/module/DateUtility'
require_relative '../rspec_helper'

describe '[Landing Page]' , :acceptance => true do
  include DateUtility

  app_title = "Care4Caregivers"

  before(:all) do
    @driver = Watir::Browser.new
    @site = Site.new(BASE_URL, @driver)

    @login = @site.loginPage
    @eula = @site.eula
    @roa = @site.roa
    @landing = @site.landing
    @lp = @site.launchpad
    @rightNav = @site.rightMenu
    @leftNav = @site.leftMenu

  end

  after(:all) do
    @site.quitDriver
  end

  context "Unauthenticated User for Landing Page" do
    it ".Landing page given a user has not authenticated - Page Header, Title, Current Date and Message" do
      Watir::Wait.until {@eula.accept_element.exists?}
      @eula.accept_element.when_visible
      expect(@eula.accept_element.text).to eq("Accept")
      @eula.accept
      @landing.appTitle_element.when_visible

      expect(@landing.appTitle).to eq(app_title)

      @landing.welcomeTitle_element.when_visible
      expect(@landing.welcomeTitle).to eq("Welcome to Care4Caregivers")

      today = getDateNthDaysAgo(0, "%B %d, %Y")
      expect(@landing.currentDate).to eq(today)

      expectedDateAndMessage = today + "\nTo directly access the Assess section, please Login to the Care4Caregivers app. Otherwise, please feel free to use the other sections of the app without logging in.\nLearn more about this application by selecting the user menu button above."
	  #expectedDateAndMessage = today + "\n" + @landing.message1 + "\n" + @landing.message2

	  messageDate = today
	  message1 = "To directly access the Assess section, please Login to the Care4Caregivers app. Otherwise, please feel free to use the other sections of the app without logging in."
      message2 = "Learn more about this application by selecting the button above."

      expect(@landing.messageDate).to eq(messageDate)
	  expect(@landing.message1).to eq(message1)
	  expect(@landing.message2).to eq(message2)
    end

    it ". Right Menu" do
      @rightNav.rightMenu_element.when_visible
      @rightNav.rightMenu

      @rightNav.about_element.when_visible
      expect(@rightNav.about_element.text).to eq("About")
      @rightNav.help_element.when_visible
      expect(@rightNav.help_element.text).to eq("Help")
      @rightNav.login_element.when_visible
      expect(@rightNav.login_element.text).to eq("Login")
      @rightNav.launchpad_element.when_visible
      expect(@rightNav.launchpad_element.text).to eq("Launchpad")


      @rightNav.rightMenu
	end


    it ". Login Button" do
      @landing.login_element.when_visible
      expect(@landing.login_element.visible?).to eq(true)

      @landing.login
      Watir::Wait.until {@login.login_element.exists?}
      @login.userName_element.when_visible
      expect(@login.userName_element.visible?).to eq(true)
      @login.password_element.when_visible
      expect(@login.password_element.visible?).to eq(true)
	  @site.goto(BASE_URL)

	end

	it ". Left Menu: The App Options icon is displayed and includes available feature navigation buttons" do
		@leftNav.leftMenu_element.when_visible
		@leftNav.leftMenu

		@leftNav.title_element.when_visible
		expect(@leftNav.title_element.text).to eq("App Options\nClose App Options Menu")

		expect(@leftNav.home_element.exists?).to eq(true)
		expect(@leftNav.learn_element.exists?).to eq(true)
		expect(@leftNav.assess_element.exists?).to eq(true)
		expect(@leftNav.manage_element.exists?).to eq(true)
		expect(@leftNav.favorites_element.exists?).to eq(true)
		expect(@leftNav.support_element.exists?).to eq(true)
	end

  end

  context "Authenticated User for Landing Page" do
    it ". Page Header, Welcome Title, Current Date" do
	  @landing.login_element.when_visible
	  @landing.login
      @login.login_with("zztest.patient01", "pass", "D123401")

      @landing.appTitle_element.when_visible

      expect(@landing.appTitle).to eq(app_title)

      @landing.welcomeTitleForAuthenticatedUser_element.when_visible
      expect(@landing.welcomeTitleForAuthenticatedUser).to eq("Welcome to Care4Caregivers")

      today = getDateNthDaysAgo(0, "%B %d, %Y")
      expect(@landing.currentDate).to eq(today)
    end


	it ". Right Menu" do
      @rightNav.rightMenu_element.when_visible()
      @rightNav.rightMenu

      @rightNav.about_element.when_visible
      expect(@rightNav.about_element.text).to eq("About")
      @rightNav.logout_element.when_visible
      expect(@rightNav.logout_element.text).to eq("Logout")
      @rightNav.launchpad_element.when_visible
      expect(@rightNav.launchpad_element.text).to eq("Launchpad")
      @rightNav.help_element.when_visible
      expect(@rightNav.help_element.text).to eq("Help")

      @rightNav.rightMenu
    end

    it ". Left Menu: The App Options icon is displayed and includes available feature navigation buttons" do

      @leftNav.leftMenu_element.when_visible
      @leftNav.leftMenu

      @leftNav.title_element.when_visible
      expect(@leftNav.title_element.text).to eq("App Options\nClose App Options Menu")

      expect(@leftNav.home_element.exists?).to eq(true)
      expect(@leftNav.learn_element.exists?).to eq(true)
      expect(@leftNav.assess_element.exists?).to eq(true)
      expect(@leftNav.manage_element.exists?).to eq(true)
      expect(@leftNav.favorites_element.exists?).to eq(true)
      expect(@leftNav.support_element.exists?).to eq(true)
    end


  end


end
