require 'rspec'
require 'watir-webdriver'

require_relative '../../lib/browser_container/site'
require_relative '../../lib/module/DateUtility'
require_relative '../rspec_helper'

describe '[App Options]', :acceptance => true do
  include DateUtility

  app_title = "Care4Caregivers"

  before(:all) do
    @driver = Watir::Browser.new
    @site = Site.new(BASE_URL, @driver)

    @login = @site.loginPage
    @eula = @site.eula
    @roa = @site.roa
    @landing = @site.landing
    @lp = @site.launchpad
    @rightNav = @site.rightMenu
    @leftNav = @site.leftMenu

  end

  after(:all) do
    @site.quitDriver
  end

  context "App Options Menu" do
    it ". When an authenticated user views the app header a menu icon is visible in the upper left hand corner" do
      acceptEulaAndQuickLogin("zztest.patient01", "pass", "D123401")

      expect(@landing.appTitle).to eq(app_title)
      @landing.welcomeTitleForAuthenticatedUser_element.when_visible
      expect(@landing.welcomeTitleForAuthenticatedUser).to eq("Welcome to Care4Caregivers")

      @leftNav.leftMenu_element.when_visible

    end

    it ". When the user selects the menu icon, a left panel is opened and displays the elements" do
      @leftNav.leftMenu

      @leftNav.title_element.when_visible
      expect(@leftNav.title_element.text).to eq("App Options\nClose App Options Menu")

      expect(@leftNav.home_element.visible?).to eq(true)
      expect(@leftNav.home_element.text).to eq("Home\nselected")
      expect(@leftNav.learn_element.visible?).to eq(true)
      expect(@leftNav.learn_element.text).to eq("Learn")
      expect(@leftNav.assess_element.visible?).to eq(true)
      expect(@leftNav.assess_element.text).to eq("Assess")
      expect(@leftNav.assess_element.visible?).to eq(true)
      expect(@leftNav.assess_element.text).to eq("Assess")
      expect(@leftNav.manage_element.visible?).to eq(true)
      expect(@leftNav.manage_element.text).to eq("Manage")
      expect(@leftNav.favorites_element.visible?).to eq(true)
      expect(@leftNav.favorites_element.text).to eq("Favorites")
      expect(@leftNav.support_element.visible?).to eq(true)
      expect(@leftNav.support_element.text).to eq("Support")

      expect(@leftNav.getNthOption(1)).to eq("Home\nselected")
      expect(@leftNav.getNthOption(2)).to eq("Learn")
      expect(@leftNav.getNthOption(3)).to eq("Assess")
      expect(@leftNav.getNthOption(4)).to eq("Manage")
      expect(@leftNav.getNthOption(5)).to eq("Support")
      expect(@leftNav.getNthOption(6)).to eq("Favorites")

      @leftNav.leftMenu

    end

  end

end
