require 'rspec'
require 'watir-webdriver'

require_relative '../../lib/browser_container/site'
require_relative '../../lib/module/DateUtility'
require_relative '../rspec_helper'

describe '[Login/Logout ]', :acceptance => true  do
  include DateUtility

  app_title = "Care4Caregivers"

  before(:all) do
    @driver = Watir::Browser.new
    @site = Site.new(BASE_URL, @driver)

    @login = @site.loginPage
    @eula = @site.eula
    @roa = @site.roa
    @landing = @site.landing
    @lp = @site.launchpad
    @rightNav = @site.rightMenu
    @leftNav = @site.leftMenu

  end

  after(:all) do
    @site.quitDriver
  end

  context "User Login/Logout Feature
           Launchpad from User Menu
           App on Launchpad" do
    it ". DS Logon" do
      Watir::Wait.until {@eula.accept_element.exists?}
      @eula.accept_element.when_visible
      @eula.accept

      @landing.login_element.when_visible
      @landing.login

      Watir::Wait.until {@login.login_element.exists?}

      expect(@login.appTitle).to eq("Department of Veterans Affairs")

      @login.login_with("zztest.patient01", "pass", "D123401")
      @landing.appTitle_element.when_visible
      expect(@landing.appTitle).to eq(app_title)

      @landing.welcomeTitleForAuthenticatedUser_element.when_visible
      expect(@landing.welcomeTitleForAuthenticatedUser).to eq("Welcome to Care4Caregivers")

    end

    it ". After authenticated in the app, the user will be able to open another app and not have to re-authenticate.  When the uer selects Launchpad from the User Menu, the system closes the app and returns to the Launchpad.  The authentication status is retained.  a button labled Care4Caregiver is displayed in Launchpad" do
      @rightNav.rightMenu_element.when_visible
      @rightNav.rightMenu
      Watir::Wait.until {@rightNav.launchpad?}
      @rightNav.launchpad_element.when_visible
      @rightNav.launchpad


      #accept Launchpad EULA if present
	  if ( @lp.lpAccept?)
		  @lp.lpAccept_element.when_visible
		  @lp.lpAccept
	  end

      Watir::Wait.until { @lp.appTitle == "Launchpad"}
      expect(@lp.appTitle).to eq("Launchpad")

      @lp.footer_element.when_visible
      expect(@lp.footer).to eq("Logged in as patient01, zztest")

	  expect(@lp.care4caregiversLink_element.text).to eq("Care for caregivers")
	  @lp.care4caregivers

      Watir::Wait.until { @landing.appTitle == app_title}
      @landing.appTitle_element.when_visible
      expect(@landing.appTitle).to eq(app_title)

	end

    it ".  When the user selects Logout, the user is logged out of all VA apps and returned to the Launchpad in an authenticated state."  do
      @rightNav.rightMenu_element.when_visible
      @rightNav.rightMenu
      Watir::Wait.until {@rightNav.logout?}
      @rightNav.logout_element.when_visible
      @rightNav.logout

      Watir::Wait.until { @lp.appTitle == "Launchpad"}
      expect(@lp.appTitle).to eq("Launchpad")

      expect(@lp.footer).to eq("Not logged in")

      @lp.care4caregivers_element.when_visible
      @lp.care4caregivers

      Watir::Wait.until { @landing.login_element.exists?}
      expect(@landing.login_element.visible?).to eq(true)

    end

  end


end
