require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'

require_relative '../../lib/browser_container/site'
require_relative '../../lib/helper/common_element'
require_relative '../../lib/pages/assess/assess'

describe 'Story# CFC-123 -Assess Main Page' , :acceptance => true do


	app_title = "Care4Caregivers"

	before(:all) do
		@driver = Watir::Browser.new
		@site = Site.new(BASE_URL, @driver)

		@login = @site.loginPage
		@eula = @site.eula
		@roa = @site.roa
		@landing = @site.landing
		@lp = @site.launchpad
		@rightNav = @site.rightMenu
		@leftNav = @site.leftMenu
		@assess = @site.assess

	end

	after(:all) do
		@site.quitDriver
	end

	context 'Navigate to Assess Main Page when not logged-in -TC# CFC-578' do
		it "should select the Assess option on the app Option menu -AC# CFC-358" do
			acceptEula()
			@landing.appTitle_element.when_visible
			expect(@landing.appTitle).to eq(app_title)
			@leftNav.leftMenu_element.when_visible
			@leftNav.leftMenu
			expect(@leftNav.assess_element.visible?).to eq(true)
			expect(@leftNav.assess_element.text).to eq("Assess")
			@leftNav.assess

		end

		it "should navigated to the login page" do
			Watir::Wait.until {@login.login_element.exists?}
			expect(@login.appTitle).to eq("Department of Veterans Affairs")
			@login.login_with("zztest.patient01", "pass", "D123401")

		end

		it "should display the Assess Main Page -AC# CFC-359" do
			@assess.primaryHeader_element.when_visible
			expect(@assess.primaryHeader).to eq("Assessment")

			@assess.firstPageContent_element.when_visible
			expect(@assess.firstPageContent).to eq("Select an item from the Left menu to see detailed information on the right.")

			expect(@assess.secondaryHeader).to eq("Assess")

			expect(@assess.getNthAssessItem(1)).to eq("Take Assessment")
			expect(@assess.getNthAssessItem(2)).to eq("Past Results")

		end

	end

	context 'Navigate to Assess Main Page when logged-in' do
		it "should select the Assess option on the app Option menu " do
			@leftNav.leftMenu_element.when_visible
			@leftNav.leftMenu
			@leftNav.home_element.when_visible
			@leftNav.home
			@leftNav.leftMenu
			@leftNav.assess_element.when_visible
			@leftNav.assess

		end

		it "should display the Assess Main Page" do
			@assess.primaryHeader_element.when_visible
			expect(@assess.primaryHeader).to eq("Assessment")

			@assess.firstPageContent_element.when_visible
			expect(@assess.firstPageContent).to eq("Select an item from the Left menu to see detailed information on the right.")
			expect(@assess.secondaryHeader).to eq("Assess")

			expect(@assess.getNthAssessItem(1)).to eq("Take Assessment")
			expect(@assess.getNthAssessItem(2)).to eq("Past Results")
		end

		it "should allow you to select Sub-Sections -AC# CFC-360" do
			@assess.takeAssessmentBtn
      		@assess.primaryHeader_element.when_visible
      		expect(@assess.primaryHeader).to eq("Assessment")
			@assess.graphPastResultsBtn
			@assess.primaryHeader_element.when_visible
			expect(@assess.primaryHeader).to eq("Assessment Results")

		end
	end
end