require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'

require_relative '../../lib/module/DBUtility'
require_relative '../../lib/module/MongoUtility'
require_relative '../../lib/browser_container/site'
require_relative '../../lib/helper/common_element'
require_relative '../../lib/pages/assess/assess'

describe 'Story# CFC-124 -Take Assessment' , :acceptance => true do
#	include DBUtility
	include MongoUtility


	app_title = "Care4Caregivers"

	before(:all) do
		# deleteAssessment is to delete assessment from MySQL
		#deleteAssessment("Zarit Caregiver Assessment")
		# removeCollection is to delete assessment from Mongo
		removeCollection("assessmentResults", "assessmentsdb")
		@driver = Watir::Browser.new
		@site = Site.new(BASE_URL, @driver)

		@login = @site.loginPage
		@eula = @site.eula
		@roa = @site.roa
		@landing = @site.landing
		@lp = @site.launchpad
		@rightNav = @site.rightMenu
		@leftNav = @site.leftMenu
		@assess = @site.assess

		acceptEula()
		@leftNav.leftMenu_element.when_visible
		@leftNav.leftMenu
		@leftNav.assess_element.when_visible
		@leftNav.assess

		if @login.login_element.exists?
			@login.login_with("zztest.patient01", "pass", "D123401")
		end
		$answerList = Array.new
		$paragraphList = @assess.getParagraphReportList()


	end

	after(:all) do
		@site.quitDriver
	end


	context 'when taking Assessment -TC# CFC-580' do

		it "should display Zarit Caregiver Assessment - Introduction page -AC# CFC-362,363" do

			expect(@assess.getNthAssessItem(1)).to eq("Take Assessment")

			@assess.takeAssessmentBtn_element.when_visible
			@assess.takeAssessmentBtn

			@assess.primaryHeader_element.when_visible
			expect(@assess.primaryHeader).to eq("Assessment")

			@assess.takeAssessmentHeader_element.when_visible
			expect(@assess.takeAssessmentHeader).to eq("Zarit Caregiver Assessment")
			expect(@assess.takeAssessmentContent).to eq('This 12-item assessment allows caregivers to self-assess their level of strain. The following screens display a series of statements about caregivers\' experiences. Related to your experience over the past week, please provide a response to each statement by selecting either "Never", "Rarely", "Sometimes", "Quite Frequently", "Nearly Always". Caregivers are asked to complete this assessment monthly. The assessment is not designed to be taken more than once per week.')

			@assess.beginBtn_element.when_visible
			expect(@assess.beginBtn_element.text()).to eq("Begin")
			@assess.beginBtn

		end

		it "should display and allow to access back button -AC# CFC-364" do
			@assess.backBtn_element.when_visible
			expect(@assess.backBtn_element.text()).to eq("Back")
			@assess.backBtn
			@assess.beginBtn_element.when_visible
			expect(@assess.beginBtn_element.text()).to eq("Begin")
			@assess.beginBtn

		end
		it "should display next -AC# CFC-365" do
			@assess.select_never
			@assess.nextBtn_element.when_visible
			expect(@assess.nextBtn_element.text()).to eq("Next")
			@assess.nextBtn
		end


		it "should display save draft button -AC# CFC-366 CFC-372" do
			@driver.execute_script("return $('.input-group-radio div:nth-of-type(2) input').click()")
			@assess.saveBtn_element.when_visible
			expect(@assess.saveBtn_element.text()).to eq("Save Draft")
			@assess.saveBtn

			@assess.save_confirmation_modal_element.when_visible
			expect(@assess.save_confirmation_modal).to eq("Confirmation")
			expect(@assess.draft_saved).to eq("Draft saved.")
			expect(@assess.ok_confirmation_element.text).to eq("OK")
			@assess.ok_confirmation
			expect(@assess.rarely_selected?).to eq(true)
			removeCollection("assessmentResults", "assessmentsdb")

		end

		it "should answer all questions -AC# CFC-367" do
			@leftNav.leftMenu
			@leftNav.assess_element.when_visible
			@leftNav.assess
			@assess.takeAssessmentBtn_element.when_visible
			@assess.takeAssessmentBtn
			@assess.beginBtn_element.when_visible
			@assess.beginBtn

			questionArr = 0
			for questionNum in 1..12

				expect(@assess.questionNumberHeading).to eq("Question " + questionNum.to_s + " of 12")

				questionList = @assess.getQuestionList()
				expect(@assess.getQuestionText(questionNum)).to eq(questionList[questionArr])

				selectionNum = @assess.generateRandomSelection()

				#puts "array[questionNum-1]: #{$answerList[questionNum-1]}"
				#puts "array[questionArr]: #{$answerList[questionArr]}"
				@driver.execute_script("$('input[name^=\"Q" + questionNum.to_s + "-\"]:eq(" + selectionNum.to_s + ")').click().click()")

				randomSelection = @driver.execute_script( "return $('input[name^=\"Q" + questionNum.to_s + "-\"]:eq(" + selectionNum.to_s + ")').attr('value')")

				$answerList << randomSelection

				@assess.nextBtn_element.when_visible
				@assess.nextBtn

				questionArr +=1

			end

			#puts $answerList.size
			#$answerList.each { |x| puts x }

		end


	end

	context 'when Submission Confirmation modal -AC# CFC-373,CFC-377' do

		it "should display confirmation modal" do
			expect(@assess.submissionConfirmation).to eq("Submission Confirmation")
		end

		it "should allow you to return to previous screen" do
			expect(@assess.submissionReturn_element.text.strip).to eq("Return")
			@assess.submissionReturn
			expect(@assess.nextBtn_element.text.strip).to eq("Submit")
			expect(@assess.backBtn_element.text.strip).to eq("Back")
			@assess.nextBtn_element.when_visible
			@assess.nextBtn
			@assess.submissionContinue_element.when_visible
			expect(@assess.submissionConfirmation).to eq("Submission Confirmation")

		end

		it "should allow you to continue to result page" do
			expect(@assess.submissionContinue_element.text.strip).to eq("Continue")
			@assess.submissionContinue
		end

	end

	context 'when Assessment Report -AC# CFC-378' do
		it "should display title of the page" do
      @assess.paragraph1_element.when_visible
			expect(@assess.assessmentReportHeader).to eq("Assessment")

		end

		it "should display print button -AC# CFC-379" do
			expect(@assess.assessmentReportPrint_element.text.strip).to eq("Print")
		end

		it "should display initial text" do
 	  		@assess.paragraph1_element.when_visible
	 		expect(@assess.paragraph1).to eq($paragraphList[0])
		end

		it "should display score text" do
			@assess.paragraph2_element.when_visible
			expect(@assess.paragraph2).to include($paragraphList[1])
		end

		it "should display recommended tools text" do
			@assess.paragraph3_element.when_visible
			expect(@assess.paragraph3).to eq($paragraphList[2])
		end

		it "should display information for Question and Answers" do
			@assess.paragraph5_element.when_visible
			expect(@assess.paragraph5).to eq($paragraphList[4])
		end

		it "should display reminder text" do
			expect(@assess.reminderText).to eq("Click the \"Set Up Reminders\" button below if you would like to be notified to retake the assessment at a future date.")
		end

		it "should display Set Up Reminders button" do
			expect(@assess.setReminder?).to eq(true)
			expect(@assess.setReminder_element.text).to eq("Set Up Reminders")
		end

		it "should display assessment title and patient name" do
			expect(@assess.assessmentTitle).to eq("Zarit Caregiver Assessment, Version 1.0")
			expect(@assess.assessmentPatient).to eq("patient01, zztest")
		end


		it "should display all questions and answers in the assessment report" do
			questionList = @assess.getQuestionList()

			for i in 1..@assess.reportQuestionAnswer_elements.length
				expect(questionList[i-1]).to include( @assess.getReportQuestion(i-1))
				expect(@assess.getReportAnswer(i-1)).to eq($answerList[i-1])
			end
		end


		it "should not allow you to take assessment again -AC# CFC-529 " do
			@leftNav.leftMenu
			@assess.takeAssessmentBtn_element.when_visible
			@assess.takeAssessmentBtn

			@assess.primaryHeader_element.when_visible
			expect(@assess.primaryHeader).to eq("Assessment")

			@assess.reassessment_element.when_visible
			expect(@assess.reassessment).to eq("It has been less than one week since you last took the self-assessment. The questions are designed to assess your symptoms since the last time you answered, so it is not helpful to take it more than once in one week. Please plan to retake the assessment in one week.")
		end

	end

end