require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'

require_relative '../rspec_helper'

require_relative '../../lib/browser_container/site'
require_relative '../../lib/helper/common_element'
require_relative '../../lib/helper/accordion_helper'
require_relative '../../lib/pages/manage/manage'
require_relative '../../lib/pages/favorites/favorites'

describe 'Story# CFC-579 - Favorites' , :acceptance => true do

	app_title = "Care4Caregivers"

	before(:all) do
		@driver = Watir::Browser.new
		@site = Site.new(BASE_URL, @driver)

		@login = @site.loginPage
		@eula = @site.eula
		@roa = @site.roa
		@landing = @site.landing
		@lp = @site.launchpad
		@rightNav = @site.rightMenu
		@leftNav = @site.leftMenu
		@manage = @site.manage
		@favorites = @site.favorites

		acceptEula()
		@leftNav.leftMenu_element.when_visible
		@leftNav.leftMenu
		@leftNav.favorites_element.when_visible
		@leftNav.favorites

		$activities = Array.new
	end

	after(:all) do
		@site.quitDriver
	end


	context 'when selecting Favorites -TC# CFC-713' do

		 it "should display the Favorites Main Page -AC# CFC-623" do
			@favorites.primaryHeader_element.when_visible
			expect(@favorites.primaryHeader).to eq("My Favorites")

			expect(@favorites.noFavorites).to eq("You do not have any favorites. To mark an item as a favorite, select the star icon for that item.")
			expect(@favorites.secondaryHeader).to eq("Favorites")

			expect(@favorites.getNthFavoritesItem(1)).to eq("My Favorites")
		 end

		 it "should display message when no favorites are selected -AC# CFC-624, 629" do
			 expect(@favorites.myFavorite?).to eq(true)
			 expect(@favorites.myFavorite_element.text.strip).to eq("My Favorites")
			 @favorites.myFavorite
			 expect(@favorites.noFavorites).to eq("You do not have any favorites. To mark an item as a favorite, select the star icon for that item.")
		 end

		it "should allow to select activities as favorites -AC# CFC-624" do
			@leftNav.leftMenu_element.when_visible
			@leftNav.leftMenu
			@leftNav.manage_element.when_visible
			@leftNav.manage

			for i in 1..@manage.manageMenuList_elements.length
				next if (@manage.getNthManageItem(i)) == "Plan a Social Activity"
				@manage.clickNthManageItem(i)
				@manage.tools
				@manage.clickNthFavorite(1)
				activity = @manage.clickNthToolItem(1)
				$activities << activity
				expect(@manage.favoriteChecked?(1)).to be(true)
			end
		end

		it "should display selected favorites -AC# CFC-624" do
			expect($activities.length).to eq(7)
			@leftNav.leftMenu
			@leftNav.favorites_element.when_visible
			@leftNav.favorites
			@favorites.myFavorite

			for i in 0..$activities.length-1
				@driver.execute_script("$('.line-heading:eq(" + i.to_s + ")').click()")
				myFavoriteActivity = @driver.execute_script("return $('.collapse .panel').children().remove().end().text().trim()")
				expect(myFavoriteActivity).to eq($activities[i])
			end
		end
	end
end