require 'rspec'
require 'watir-webdriver'
require 'json'

require_relative '../../lib/pages/learn/learn'
require_relative '../../lib/browser_container/site'
require_relative '../../lib/helper/common_element'
require_relative '../rspec_helper'



describe '[Story# CFC-118 - Learn]', :acceptance => true do

	app_title = "Care4Caregivers"

	before(:all) do
		@driver = Watir::Browser.new
		@site = Site.new(BASE_URL, @driver)

		@eula = @site.eula
		@landing = @site.landing
		@lp = @site.launchpad
		@rightNav = @site.rightMenu
		@leftNav = @site.leftMenu
		@learn = @site.learn

	end

	after(:all) do
		@site.quitDriver
	end

	context "when learn categories are selected -TC# CFC-562" do

			it "should display learn section" do
			acceptEula()

			@leftNav.leftMenu_element.when_visible
			@leftNav.leftMenu

			@leftNav.title_element.when_visible
			expect(@leftNav.learn_element.text).to eq("Learn")

			@leftNav.learn
			@learn.secondaryHeader_element.when_visible
			expect(@learn.secondaryHeader_element.text).to eq("Learn")

		end


		it "should display section in emotional consequences -TC# CFC-565" do
			@learn.emotional_consequences

			category = 0

			for i in 0..$learnJson[category]['subCategories'].length-1
				subcategory = $learnJson[category]['subCategories'][i]['title']

				expect(@learn.isAccordionExpanded($learnJson[category]['subCategories'][i]['title'])).to eq(false)
				expect(@learn.getTitleForLearnSubCategory(category, i)).to eq(@learn.getAccordianTextByIndex(i))

				@learn.clickAccordianByIndex(i)
				expect(@learn.isDownArrowIconDisplayed($learnJson[category]['subCategories'][i]['title'])).to eq(true)

				for j in 0..$learnJson[category]['subCategories'][i]['articles'].length-1
					articleId = $learnJson[category]['subCategories'][i]['articles'][j]['id']
					expect($learnJson[category]['subCategories'][i]['articles'][j]['title']).to eq(@learn.getSubcategoryText(subcategory, articleId))
					@learn.clickSubcategoryContent(subcategory, articleId)
					expect(@learn.getArticleContentById(articleId).strip.gsub(/<[^>]*>/ui,'')).to eq(@learn.content_element.inner_html.strip.gsub(/<[^>]*>/ui,''))
					@learn.back

				end

			end
		end

		it "should display section in take care of yourself -TC# CFC-566" do
			@learn.take_care_of_yourself
			category = 1

			for i in 0..$learnJson[category]['subCategories'].length-1
				subcategory = $learnJson[category]['subCategories'][i]['title']


				expect(@learn.isAccordionExpanded($learnJson[category]['subCategories'][i]['title'])).to eq(true)
				expect(@learn.getTitleForLearnSubCategory(category, i)).to eq(@learn.getSingleAccordianText())

				@learn.clickAccordianByIndex(i)
				expect(@learn.isDownArrowIconDisplayed($learnJson[category]['subCategories'][i]['title'])).to eq(false)
				@learn.clickAccordianByIndex(i)

				for j in 0..$learnJson[category]['subCategories'][i]['articles'].length-1
					articleId = $learnJson[category]['subCategories'][i]['articles'][j]['id']
					expect($learnJson[category]['subCategories'][i]['articles'][j]['title']).to eq(@learn.getSubcategoryText(subcategory, articleId))
					@learn.clickSubcategoryContent(subcategory, articleId)
					expect(@learn.getArticleContentById(articleId).strip.gsub(/<[^>]*>/ui,'')).to eq(@learn.content_element.inner_html.strip.gsub(/<[^>]*>/ui,''))
					@learn.back

				end

			end
		end


		it "should display section in Build Resilience -TC# CFC-567" do
			@learn.build_resilience
			category = 2

			for i in 0..$learnJson[category]['subCategories'].length-1
				subcategory = $learnJson[category]['subCategories'][i]['title']

				expect(@learn.isAccordionExpanded($learnJson[category]['subCategories'][i]['title'])).to eq(false)
				expect(@learn.getTitleForLearnSubCategory(category, i)).to eq(@learn.getAccordianTextByIndex(i))

				@learn.clickAccordianByIndex(i)
				expect(@learn.isDownArrowIconDisplayed($learnJson[category]['subCategories'][i]['title'])).to eq(true)

				for j in 0..$learnJson[category]['subCategories'][i]['articles'].length-1
					articleId = $learnJson[category]['subCategories'][i]['articles'][j]['id']
					expect($learnJson[category]['subCategories'][i]['articles'][j]['title']).to eq(@learn.getSubcategoryText(subcategory, articleId))
					@learn.clickSubcategoryContent(subcategory, articleId)
					expect(@learn.getArticleContentById(articleId).strip.gsub(/<[^>]*>/ui,'')).to eq(@learn.content_element.inner_html.strip.gsub(/<[^>]*>/ui,''))
					@learn.back

				end

			end
		end


		it "should display section in Manage Stress -TC# CFC-564" do
			@learn.manage_stress
			category = 3

			for i in 0..$learnJson[category]['subCategories'].length-1
				subcategory = $learnJson[category]['subCategories'][i]['title']

				expect(@learn.isAccordionExpanded($learnJson[category]['subCategories'][i]['title'])).to eq(true)
				expect(@learn.getTitleForLearnSubCategory(category, i)).to eq(@learn.getSingleAccordianText())

				@learn.clickAccordianByIndex(i)
				expect(@learn.isDownArrowIconDisplayed($learnJson[category]['subCategories'][i]['title'])).to eq(false)
				@learn.clickAccordianByIndex(i)

				for j in 0..$learnJson[category]['subCategories'][i]['articles'].length-1
					articleId = $learnJson[category]['subCategories'][i]['articles'][j]['id']
					expect($learnJson[category]['subCategories'][i]['articles'][j]['title']).to eq(@learn.getSubcategoryText(subcategory, articleId))
					@learn.clickSubcategoryContent(subcategory, articleId)
					expect(@learn.getArticleContentById(articleId).strip.gsub(/<[^>]*>/ui,'')).to eq(@learn.content_element.inner_html.strip.gsub(/<[^>]*>/ui,''))
					@learn.back

				end

			end
		end

		it "should display section in Manage Relationships -TC# CFC-563" do
			@learn.manage_relationships
			category = 4

			for i in 0..$learnJson[category]['subCategories'].length-1
				subcategory = $learnJson[category]['subCategories'][i]['title']

				expect(@learn.isAccordionExpanded($learnJson[category]['subCategories'][i]['title'])).to eq(false)
				expect(@learn.getTitleForLearnSubCategory(category, i)).to eq(@learn.getAccordianTextByIndex(i))

				@learn.clickAccordianByIndex(i)
				expect(@learn.isDownArrowIconDisplayed($learnJson[category]['subCategories'][i]['title'])).to eq(true)

				for j in 0..$learnJson[category]['subCategories'][i]['articles'].length-1
					articleId = $learnJson[category]['subCategories'][i]['articles'][j]['id']
					expect($learnJson[category]['subCategories'][i]['articles'][j]['title']).to eq(@learn.getSubcategoryText(subcategory, articleId))
					@learn.clickSubcategoryContent(subcategory, articleId)
					expect(@learn.getArticleContentById(articleId).strip.gsub(/<[^>]*>/ui,'')).to eq(@learn.content_element.inner_html.strip.gsub(/<[^>]*>/ui,''))
					@learn.back

				end

			end
		end

	end
end



