
require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'

require_relative '../rspec_helper'

require_relative '../../lib/browser_container/site'
require_relative '../../lib/helper/common_element'
require_relative '../../lib/helper/accordion_helper'
require_relative '../../lib/pages/assess/assess'
require_relative '../../lib/pages/manage/manage'

describe 'Story# CFC-127, CFC-128, CFC-131 - Manage and Tools' , :acceptance => true do

	app_title = "Care4Caregivers"

	before(:all) do
		@driver = Watir::Browser.new
		@site = Site.new(BASE_URL, @driver)

		@login = @site.loginPage
		@eula = @site.eula
		@roa = @site.roa
		@landing = @site.landing
		@lp = @site.launchpad
		@rightNav = @site.rightMenu
		@leftNav = @site.leftMenu
		@manage = @site.manage

		acceptEula()
		@leftNav.leftMenu_element.when_visible
		@leftNav.leftMenu
		@leftNav.manage_element.when_visible
		@leftNav.manage

	end

	after(:all) do
		@site.quitDriver
	end

	context 'Subsections -AC# CFC-289, 292, 293, 294, 295 -AC# CFC-296, 299, 300, 301,302, 303, 304, 305, 306, 307, 309 -AC# 343' do

		it "should allow to select Take a Timeout and Tools -TC# CFC-600, -TC# CFC-709" do
			@manage.takeATimeOut_element.when_visible
			@manage.takeATimeOut
			assertManageRandomData('./data/manage/TakeATimeOut.json')
			@manage.takeATimeOut
			assertManageTools('./data/manage/TakeATimeOut.json')
		end

		it "should allow to select Inspiring Quotes and Tools -TC# CFC-600, -TC# CFC-709" do
			@manage.inspiringQuotes
			assertManageInspiringQuotesRandomData('./data/manage/InspiringQuotes.json')
			@manage.inspiringQuotes
			assertManageInspiringQuotesTools('./data/manage/InspiringQuotes.json')
		end

		it "should allow to select Pleasant Events and Tools -TC# CFC-600, -TC# CFC-709" do
			@manage.pleasantEvents
			assertManageRandomData('./data/manage/PleasantEvents.json')
			@manage.pleasantEvents
			assertManageTools('./data/manage/PleasantEvents.json')
		end

		it "should allow to select Distract Yourself and Tools -TC# CFC-600, -TC# CFC-709" do
			@manage.distractYourself
			assertManageRandomData('./data/manage/DistractYourself.json')
			@manage.distractYourself
			assertManageTools('./data/manage/DistractYourself.json')
		end

		it "should allow to select Soothe Yourself and Tools -TC# CFC-600, -TC# CFC-709" do
			@manage.sootheYourself
			assertManageRandomData('./data/manage/SootheYourself.json')
			@manage.sootheYourself
			assertManageTools('./data/manage/SootheYourself.json')
		end

		it "should allow to select Change Perspective and Tools -TC# CFC-600, -TC# CFC-709" do
			@manage.changePerspective
			assertManageRandomData('./data/manage/ChangePerspective.json')
			@manage.changePerspective
			assertManageTools('./data/manage/ChangePerspective.json')
		end

		it "should allow to select Relax Yourself Tools -TC# CFC-600, CFC-673, -TC# CFC-709" do
			@manage.relaxYourself
			assertManageRelaxYourselfTools('./data/manage/RelaxYourself.json')
		end

	end

	context 'Help Section -TC# CFC-600' do

		it "should display help button -AC# CFC-291" do
			clickHelp
			expect(@manage.helpHeader).to eq("Help")
		end

		it "should display each manage section -AC# CFC-291" do
			assertHelpContent('./data/manage/ToolCategories.json')
		end

		it "should selecting x button close the modal -AC# CFC-291" do
			expect(@manage.modalDialog_element).to be_visible
			closeHelp
			@manage.modalDialog_element.when_not_visible
			expect(@manage.modalDialog_element).to_not be_visible
		end

	end


	def assertHelpContent(categoryFile)
		$path = File.read(categoryFile)
		$json = JSON.parse($path.to_s())
		$sortedKeys = $json.keys.sort
		for i in 0..$sortedKeys.length-1
				k = i+2
				helpTitle = @driver.execute_script("return $('.modal-content div:nth-of-type(" + k.to_s + ") p:nth-of-type(1)').text()")
				helpContent = @driver.execute_script("return $('.modal-content div:nth-of-type(" + k.to_s + ") p:nth-of-type(2)').text()")

				if helpTitle == $json[$sortedKeys[i]]['Title']
					expect($json[$sortedKeys[i]]['HelpText']).to eq(helpContent)
					#break
				end
		end

	end


	def assertManageTools(categoryFile)
		$path = File.read(categoryFile)
		$json = JSON.parse($path.to_s())
		$sortedKeys = $json.keys.sort

		@manage.tools

		expect(@manage.toolsList_elements.length).to eq($sortedKeys.length)

		for i in 0..$sortedKeys.length-1
			expect(@manage.toolsList_elements[i].text).to eq($sortedKeys[i])
		end

		for i in 0..@manage.toolsList_elements.length-1
			@manage.toolsList_elements[i].click
			expect(@manage.toolHeading).to eq($sortedKeys[i])
			expect(@manage.toolDescription).to eq($json[$sortedKeys[i]]['TextBody'])
			@manage.toolsBack
		end
	end

	def assertManageRandomData(categoryFile)
		$path = File.read(categoryFile)
		$json = JSON.parse($path.to_s())
		$sortedKeys = $json.keys.sort

		for j in 0..2
			for i in 0..$sortedKeys.length
				heading = @manage.toolHeading
				if heading == $sortedKeys[i]
					expect(@manage.toolDescription).to eq($json[$sortedKeys[i]]['TextBody'])
					break
				end
			end
			expect(@manage.tryAnother?).to be(true)
			expect(@manage.tryAnother_element.text).to eq("Try Another")
			@manage.tryAnother
			@driver.execute_script("$('#favoriteButton').click()")
		end
		expect(@manage.done?).to be(true)
		expect(@manage.done_element.text).to eq("Done")
		@manage.done

	end


	def assertManageRelaxYourselfTools(categoryFile)
		$path = File.read(categoryFile)
		$json = JSON.parse($path.to_s())
		$sortedKeys = $json.keys.sort

		expect(@manage.tools_element.text).to eq('Tools')
		@manage.tools

		expect(@manage.toolsList_elements.length).to eq($sortedKeys.length)

		for i in 0..$sortedKeys.length-1
			expect(@manage.toolsList_elements[i].text).to eq($sortedKeys[i])
		end
=begin
		for i in 0..@manage.toolsList_elements.length-1
			@manage.toolsList_elements[i].click
			puts "@manage.toolDescription #{@manage.toolDescription}"
			puts "$json[$sortedKeys[i]]['TextBody']: #{$json[$sortedKeys[i]]['TextBody']}"
			expect(@manage.toolDescription).to eq($json[$sortedKeys[i]]['TextBody'])
			@manage.toolsBack
		end
=end

	end

	def assertManageInspiringQuotesTools(categoryFile)
		$path = File.read(categoryFile)
		$json = JSON.parse($path.to_s())
		$sortedKeys = $json.keys.sort

		expect(@manage.tools_element.text).to eq('Tools')
		@manage.tools

		expect(@manage.toolsList_elements.length).to eq($sortedKeys.length)

		for i in 0..$sortedKeys.length-1
			expect(@manage.toolsList_elements[i].text).to eq($sortedKeys[i])
		end

		for i in 0..@manage.toolsList_elements.length-1
			@manage.toolsList_elements[i].click
			expect(@manage.toolDescription).to eq($json[$sortedKeys[i]]['TextBody'])
			@manage.toolsBack
		end
	end

	def assertManageInspiringQuotesRandomData(categoryFile)
		$path = File.read(categoryFile)
		$json = JSON.parse($path.to_s())
		$sortedKeys = $json.keys.sort
		for i in 0..$sortedKeys.length
			description = @manage.toolDescription
			if description == $sortedKeys[i]
				expect(@manage.toolDescription).to eq($json[$sortedKeys[i]]['TextBody'])
				break
			end

		end
	end

	def clickHelp()
		@driver.execute_script("$('.icon-help').click()")
	end

	def closeHelp()
		@driver.execute_script("$('.primary-header span').click()")
	end
end