require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'

require_relative '../rspec_helper'

require_relative '../../lib/browser_container/site'
require_relative '../../lib/helper/common_element'
require_relative '../../lib/helper/accordion_helper'
require_relative '../../lib/pages/assess/assess'
require_relative '../../lib/pages/manage/manage'

describe 'Story# CFC-130 - Manage - Plan a Social Activity' , :acceptance => true do

	app_title = "Care4Caregivers"

	before(:all) do
		@driver = Watir::Browser.new
		@site = Site.new(BASE_URL, @driver)

		@login = @site.loginPage
		@eula = @site.eula
		@roa = @site.roa
		@landing = @site.landing
		@lp = @site.launchpad
		@rightNav = @site.rightMenu
		@leftNav = @site.leftMenu
		@manage = @site.manage

		acceptEula()
		@leftNav.leftMenu_element.when_visible
		@leftNav.leftMenu
		@leftNav.manage_element.when_visible
		@leftNav.manage

		$activities = Array.new
	end

	after(:all) do
		@site.quitDriver
	end


	context 'Accessing Plan a Social Activity -TC# CFC-675' do

		it "should allow to access Plan a Social Activity from menu -AC# CFC-329" do
			expect(@manage.getNthManageItem(2)).to eq("Plan a Social Activity")
			@manage.planASocialActivity_element.when_visible
			@manage.planASocialActivity
		end

		it "should display introductory text" do
			expect(@manage.planASocialActivityIntro).to eq("Use this tool to plan more social activities in your life. Regular social activity will help you stay connected and cope with stress better. The tool will assist in choosing people and an activity to do together. Think about inviting family members, friends, co-workers, people from your neighborhood or spiritual community, people you want to get to know better, etc.")
		end

	end

	context 'Make a plan -TC# CFC-675' do

		it "should display and allow you to select Make a Plan button -AC# CFC-332,341,333" do
			expect(@manage.makeAPlan_element.text).to eq("Make a Plan")
			@manage.makeAPlan
			expect(@manage.favoriteBtn?).to eq(true)
			expect(@manage.planBack?).to eq(true)
			@manage.planBack_element.click()
			@manage.makeAPlan_element.when_visible
			@manage.makeAPlan
		end

		it "should display list of activities -AC# CFC-334" do
			assertPlanASocialActivity('./data/manage/PlanAsocialActivity.json')
		end

	end


	def assertPlanASocialActivity(categoryFile)
		$path = File.read(categoryFile)
		$json = JSON.parse($path.to_s())
		$sortedKeys = $json.keys.sort

		expect(@manage.toolsList_elements.length).to eq($sortedKeys.length)

		for i in 0..$sortedKeys.length-1
			expect(@manage.toolsList_elements[i].text).to eq($sortedKeys[i])
		end

		for i in 1..3
			@manage.clickNthFavorite(i)
			activity = @manage.toolsList_elements[i-1].text
			$activities << activity
			expect(@manage.favoriteChecked?(i)).to be(true)
		end
		@manage.favoriteBtn
		expect($activities.length).to eq(3)

		for i in 0..$activities.length-1
			expect(@manage.toolsList_elements[i].text).to eq($activities[i])
		end

	end


end