require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'

require_relative '../rspec_helper'

require_relative '../../lib/browser_container/site'
require_relative '../../lib/helper/common_element'
require_relative '../../lib/helper/accordion_helper'
require_relative '../../lib/pages/assess/assess'
require_relative '../../lib/pages/manage/manage'
require_relative '../../lib/pages/support/support'

describe 'Story# CFC-133, CFC-135, CFC-132  - Support - Get Support Right Now And Resources' , :acceptance => true do


	app_title = "Care4Caregivers"

	before(:all) do
		@driver = Watir::Browser.new
		@site = Site.new(BASE_URL, @driver)

		@login = @site.loginPage
		@eula = @site.eula
		@roa = @site.roa
		@landing = @site.landing
		@lp = @site.launchpad
		@rightNav = @site.rightMenu
		@leftNav = @site.leftMenu
		@manage = @site.manage
		@support = @site.support

		acceptEula()
		@leftNav.leftMenu_element.when_visible
		@leftNav.leftMenu
		@leftNav.support_element.when_visible
		@leftNav.support

	end

	after(:all) do
		@site.quitDriver
	end

	context 'when Support is selected -TC# CFC-652' do

		it "should display the Support Main Page" do
			@support.primaryHeader_element.when_visible
			expect(@support.primaryHeader).to eq("Support")

			@support.firstPageContent_element.when_visible
			expect(@support.firstPageContent).to eq("Select an item from the Support list to view details.")
			expect(@support.secondaryHeader).to eq("Support")

			expect(@support.getNthOption(1)).to eq("Get Support Right Now")
			expect(@support.getNthOption(2)).to eq("Resources")
		end

		it "should display content on the get support right now -AC# CFC-267, 269" do
			@support.getSupportRightNow
			@support.primaryHeader_element.when_visible
			expect(@support.primaryHeader).to eq("Crisis Resources")
			expect(@support.getSupportContent_element.text.strip.gsub!(/[\n\t]*/,'')).to eq("For any crisis, including medical emergencies:Call 911Veteran Crisis Line (Veterans and service members press 1 after you connect):Call 1-800-273-8255Caregivers Support Line:Call 1-855-260-3274Disclaimer: Auto-dialing functionality is browser and device dependent. You may have to manually dial the phone number to place a call.")
		end

		it "should display content on the resources -AC# CFC-282" do
			resourceContent =  "VA Caregiver ResourcesCaregiver Support Line1-855-260-3274 (Toll-free)Find the support you need to provide the best care. Whether you could use some help at home or you just need someone to listen, we're here to support you.Caregiver ServicesLearn more about the variety of services available to Family Caregivers. This resource can help you find nearby assistance.New Services for Family Caregivers of Post-9/11 VeteransIf you are the Family Caregiver of a Veteran who was injured post-9/11, you may be eligible for additional services through VA. Learn about the newest services to see if you are eligible.Staying StrongStaying strong for the Veteran you love and your family can feel exhausting. Acquire information and tips to help you stay strong and informed.Caregiver ToolboxThe VA Caregiver Toolbox offers resources and information to help you stay on top of things and manage the daily stresses of caregiving.Non-VA Caregiver ResourcesNational Alliance for Caregiving (NAC)The National Alliance for Caregiving is a non-profit coalition of national organizations focusing on issues of family caregiving.Family Caregiver Alliance (FCA)FCA was the first community-based nonprofit organization in the country to address the needs of families and friends providing long-term care at home.Next Step in CareNext Step in Care provides easy-to-use guides to help family caregivers. Guides are provided in several languages.Eldercare Locator1-800-677-1116Eldercare Locator is a public service that provides useful resources and information about senior services in your community.Disclaimer: Auto-dialing functionality is browser and device dependent. You may have to manually dial the phone number to place a call."

			@support.resources
			@support.primaryHeader_element.when_visible
			expect(@support.primaryHeader).to eq("Resources")
			expect(@support.getSupportContent_element.text.strip.gsub!(/[\n\t]*/,'')).to eq(resourceContent)
		end
	end


end