define(['angular', 'app'], function (angular, app) {
	'use strict';

	app.controller('SecondaryNavigationController', function ($scope, $q, $state, $filter, $injector, $modal) {

		$scope.dataPointers = {};
		$scope.listItemTemplateUrl = "src/container/components/content/secondary-navigation/secondary-navigation-item_template.html";

		var baseState = null;

		$scope.$on('$stateChangeSuccess', function (event, toState, toParams, fromState, fromParams) {
			$scope.secondaryNavTitle = toState.data.appletName;
			$scope.headerButton = $state.current.data.headerButton;

			var tokenizedStateName = toState.name.split(".");
			var baseStateName = tokenizedStateName.slice(0, tokenizedStateName.indexOf("secondary-navigation") + 2).join(".");
			var stateTester = new RegExp("^" + baseStateName + ".?[A-Za-z\-]*$");

			var stateList = $state.get();
			baseState = $state.get(baseStateName);

			var validStateList = [];

			function addListButtonClass(data){
				var uniqueClass = data.sectionName.replace(/\s/g, "-").replace(/\//ig, "-").toLowerCase();
				if(localStorage.getItem('c4c-recommendations') && localStorage.getItem('c4c-recommendations') !== "undefined"){
					var recommendations = [];
					for (var i = 0; i < JSON.parse(localStorage.getItem('c4c-recommendations')).length; i++){
						recommendations[i] = JSON.parse(localStorage.getItem('c4c-recommendations'))[i].name.replace(/\s/g, "-").replace(/\//ig, "-").toLowerCase();
					}
				}
				if(data.class) {
					if(data.class.indexOf(uniqueClass) === -1) {
						data.class = data.class + " " + uniqueClass;
					}
				} else {
					data.class = uniqueClass;
				}
				if(recommendations){
					if(recommendations.indexOf(uniqueClass) > -1) {
						data.class += ' recommendation';
						data.aria = data.sectionName + ' Recommended Activity not Accomplished';
						data.recommended = true;
						$scope.recommended = true;
					}
				}
			}

			stateList.forEach(function(state){
				if(stateTester.test(state.name)) {
					if(state.data.paramSections && state.data.baseStateName === state.name) {
						state.data.paramSections.forEach(function(data){
							data.stateName = data.stateName || state.name;
							data.initialState = data.initialState || state.data.initialState;
							addListButtonClass(data);
						});
						validStateList = validStateList.concat(state.data.paramSections);
					} else if(state.data.sectionName) {
						addListButtonClass(state.data);
						state.data.stateName = state.name;
						validStateList.push(state.data);
					}
				}
			});

			var filterPromise;
			
			if(baseState.data.filter) {
				filterPromise = $injector.invoke([baseState.data.filter, function (navFilter) {
					return navFilter.filter(validStateList);
				}]);
			} else {
				filterPromise = $q.when(validStateList);
			}

			filterPromise.then(function(validStateList){
				$scope.dataPointers.list = $filter("orderBy")(validStateList, "sectionIndex");
			});

		});

		$scope.headerButtonClick = function(){
			var tmpFn = function(headerButtonService) {
				headerButtonService.onClick();
			};
			tmpFn.$inject = [$state.current.data.headerButton.service];
			$injector.invoke(tmpFn);
		};

		$scope.isSelected = function(item) {
			if(!item.paramValue) {
				return $state.includes(item.stateName);
			} else {
				return $state.includes(item.stateName, {section: item.paramValue})
			}
		};

		$scope.getDetails = function(item) {
			if(item.name) {
				$state.go(item.name + (item.initialState ? ("." + item.initialState) : ""));
			} else {
				$state.go(item.stateName + (item.initialState ? ("." + item.initialState) : ""), {section: item.paramValue});
			}
		};

		$scope.help = function(){
			$modal.open({
				windowTemplateUrl: 'src/ui-components/modals/helper/modal-window_template.html',
				templateUrl: 'src/modules/manage/pages/help/manage-help_template.html',
				controller: 'ManageHelpController'
			})
		}
	});
});