define(['angular', 'app', 'mhpuser_service', 'localResourceDirectoryService'], function (angular, app) {
	"use strict";
	app.factory('assessment', function ($http, $q, $filter, mhpuser, localResourceDirectoryService) {

		var assessment = {
			'title': "",
			'id': "",
			'resultID': "",
			'version': "",
			'notes': "",
			'inProgress': "",
			'score': "",
			'dateTaken': "",
			'questions': null,
			'raw-questions': null,
			'questionOrder': null,
			'selectedValues': null
		};

		var _assessment = {
			'links': null
		};

		assessment.init = function (assessmentID) {
			var deferred = $q.defer(assessment);

			_assessment.fetchAssessment(assessmentID).then(function () {
				deferred.resolve(assessment);
			}, function (error) {
				deferred.reject(error);
			});

			return deferred.promise;
		};

		assessment.initAsDraft = function (assessmentID) {
			var deferred = $q.defer();

			_assessment.checkEligibility(assessmentID).then(function () {
				_assessment.fetchAssessment(assessmentID).then(function () {
					_assessment.fetchDraft(assessmentID).then(function () {
						// assessment.postCurrentResponses();
						deferred.resolve(assessment);
					}, function (error) {
						deferred.reject(error);
					});
				}, function (error) {
					deferred.reject(error);
				});
			}, function (error) {
				deferred.reject(error);
			});
			return deferred.promise;
		};

		assessment.initAsResult = function (assessmentID, resultID) {
			var deferred = $q.defer();

			_assessment.fetchAssessment(assessmentID).then(function () {
				_assessment.fetchResults(assessmentID, resultID).then(function (assessmentData) {
					deferred.resolve(assessmentData);
				}, function (error) {
					deferred.reject(error);
				});
			}, function (error) {
				deferred.reject(error);
			});

			return deferred.promise;
		};

		assessment.initWithCachedResultResponse = function (assessmentID, cachedResultResponse) {
			var deferred = $q.defer();

			_assessment.fetchAssessment(assessmentID).then(function () {
				if (cachedResultResponse['id'] === assessmentID) {
					_assessment.setAssessmentResponse(cachedResultResponse);
					deferred.resolve();
				} else {
					deferred.reject("ID MISMATCH");
				}
			}, function () {
				deferred.reject();
			});

			return deferred.promise;
		};


		assessment.saveDraft = function () {
			return _assessment.postResponse(_assessment.getPostDataObject(true));
		};

		assessment.submit = function () {
			return _assessment.postResponse(_assessment.getPostDataObject(false));
		};

		assessment.fetchResults = function(assessmentID, resultID){
			return _assessment.fetchResults(assessmentID, resultID);
		}
		//add assessmentDirectory links to resource directory
		_assessment.getAssessmentLinks = function (assessmentID) {
			_assessment['links'] = $q.defer();

			mhpuser.fetch().then(
				function (mhpuser) {
					var assigningAuthority = mhpuser.userIdentifier.assigningAuthority;
					var uniqueId = mhpuser.userIdentifier.uniqueId;
					localResourceDirectoryService.fetch().then(function(response){
						_assessment['links'].resolve(response);
					});
				}
			);
			return _assessment['links'].promise;
		}

		_assessment.checkEligibility = function (assessmentID) {
			var deferred = $q.defer();
			_assessment.getAssessmentLinks(assessmentID).then(function (links) {
					$http.get(links["patient-assessment-eligibility"]).success(function (response) {
						if (response.eligibile) {
							deferred.resolve();
						} else {
							deferred.reject({'error': "NOT ELIGIBLE", 'rootResponse': response});
						}
					}).error(function (error) {
						deferred.reject(error);
					});
				},
				function () {
					deferred.reject();
				});

			return deferred.promise;
		};


		_assessment.fetchAssessment = function (assessmentID) {
			var deferred = $q.defer();
			_assessment.getAssessmentLinks(assessmentID).then(function (links) {
					$http.get(links["patient-assessment"]).success(function (response) {
						assessment['id'] = response['id'];
						assessment['title'] = response['uniqueTitle'];
						assessment['notes'] = response['notes'];
						assessment['version'] = response['version'];
						assessment['raw-questions'] = response['question'];

						assessment['questions'] = new Array();

						assessment.questions = assessment['raw-questions'].map(function (question, i) {
							var qid = question['id'];

							var object = {};
							object.id = question.id;
							object.prompt = question.prompt;
							object.type = question.type;
							object.questionNumber = question.questionNumber;

							switch (question.type) {
								case "SLIDER":
									object.property = {};
									question.questionProperty.forEach(function (property) {
										object.property[property.name] = property.value;
									});
									break;
								case "FREE_TEXT":
									object.maxLength = question.questionProperty[0].value;
									break;
								case "MULTI_OPTION_SINGLE_RESPONSE":
									object.choices = [];
									question.questionChoice.forEach(function (choice) {
										object.choices.push(choice.property[0].value);
									});
									break;
								case "MULTI_OPTION_MULTI_RESPONSE_NONE_AVAILABLE":
									var none = {'label': 'None of the Above', 'type': 'NONE'};
								case "MULTI_OPTION_MULTI_RESPONSE":
								default:
									object.choices = [];
									question.questionChoice.forEach(function (choice) {
										object.choices.push({'label': choice.property[0].value, 'type': 'DEFAULT'});
									});
									if (none) {
										object.choices.push(none);
										none = null;
									}
							}

							return object;
							// assessment.questions.push(object);

						});

						deferred.resolve();

					}).error(function (response) {
						deferred.reject();
					});

				},
				function () {
					deferred.reject();
				});

			return deferred.promise;

		};


		//draft set of questions + selections

		_assessment.fetchDraft = function (assessmentID) {
			var deferred = $q.defer();

			_assessment.getAssessmentLinks(assessmentID).then(function (links) {
					$http.get(links["patient-assessment-draft"])
						.success(function (response) {

							_assessment.setAssessmentResponse(response);
							// }
							deferred.resolve()
						})
						.error(function (response) {
							deferred.reject()
						});
				},
				function () {
					deferred.reject();
				});

			return deferred.promise;
		};

		_assessment.fetchResults = function (assessmentID, resultID) {

			var deferred = $q.defer();

			_assessment.getAssessmentLinks(assessmentID).then(function (links) {
					$http.get(links["patient-assessment-results"] + "/" + resultID)
						.success(function (response) {
							deferred.resolve(response);
						})
						.error(function (response) {
							deferred.reject();
						});
				},
				function () {
					deferred.reject();
				});

			return deferred.promise
		}


		_assessment.setAssessmentResponse = function (httpResponse) {

			assessment['resultID'] = httpResponse['dataIdentifier']['uniqueId'];

			if (assessment['resultID'] !== "placeHolderAssessmentResult") {
				assessment['inProgress'] = httpResponse['inProgress'];
				assessment['score'] = httpResponse['score'];
				assessment['dateTaken'] = httpResponse['dateTaken'];
				httpResponse['assessmentResponse'].forEach(function (resp) {
					var qid = resp['question']['id'];
					var question = assessment.questions[resp.question.questionNumber - 1];
					//index 0 holds a special value signifying either none or range value
					var properties = resp['assessmentQuestionChoice'][0]['property'];
					switch (question.type) {
						case "SLIDER":
						case "FREE_TEXT":
							properties.forEach(function (property) {
								if (property.name === "selectedValue") {
									question.selectedValue = property.value;
									question.selectionMade = true;
								}
							});
							break;
						case "MULTI_OPTION_SINGLE_RESPONSE":
							properties.forEach(function (property) {
								if (property.name === "displayText") {
									question.choices.forEach(function (choice) {
										if (choice === property.value || choice.type === 'NONE' && property.value === 'NONE') {
											question.selectedValue = choice;
											question.selectionMade = true;
										}
									});
								}
							});
						case "MULTI_OPTION_MULTI_RESPONSE_NONE_AVAILABLE":
						case "MULTI_OPTION_MULTI_RESPONSE":
							properties.forEach(function (property) {
								if (property.name === "displayText") {
									question.choices.forEach(function (choice) {
										if (choice.label === property.value || choice.type === 'NONE' && property.value === 'NONE') {
											choice.selected = true;
											question.selectionMade = true;
										}
									});
								}
							});
						default:


					}
				});
			}

			return assessment;

		};


		_assessment.getPostDataObject = function (isDraft) {

			var postObject = new Object();
			var date = new Date();


			postObject['assessmentId'] = assessment.id;
			postObject['uniqueTitle'] = assessment.title;
			postObject['version'] = assessment.version;
			postObject['inProgress'] = isDraft;
			postObject['assessmentResponse'] = new Array();
			postObject['dateTaken'] = (date.getMonth() + 1) + "/" + date.getDate() + "/" + date.getFullYear() + " " + date.getHours() + ":" + date.getMinutes() + ":" + date.getSeconds();//postObject['dateTaken'].substr(0,10) + " " + postObject['dateTaken'].substr(11,8);


			assessment.questions.forEach(function (question, i) {
				if (_assessment.selectionMade(i)) {
					var assessmentQuestionChoice = [
						{'object-type': "AssessmentQuestionChoice", 'property': new Array()}
					];
					switch (question.type) {
						case "SLIDER":
						case "FREE_TEXT":
							assessmentQuestionChoice[0].property.push({'name': 'selectedValue', 'object-type': 'AssessmentProperty', 'value': question.selectedValue});
							break;
						case "MULTI_OPTION_SINGLE_RESPONSE":
						case "MULTI_OPTION_MULTI_RESPONSE_NONE_AVAILABLE":
						case "MULTI_OPTION_MULTI_RESPONSE":
						default:
							var currentQuestion = question;
							question.choices.forEach(function (choice, j) {
								if (choice == currentQuestion.selectedValue) {
									if (choice.type === "NONE") {
										assessmentQuestionChoice[0].property.push({'name': 'displayText', 'object-type': 'AssessmentProperty', 'value': "NONE"});
									} else {
										assessmentQuestionChoice[0].property = assessmentQuestionChoice[0].property.concat(assessment['raw-questions'][i].questionChoice[j].property);
									}
								};
							});

					}

					postObject['assessmentResponse'].push({'question': assessment['raw-questions'][i], 'assessmentQuestionChoice': assessmentQuestionChoice});
				}


			});
			return postObject;

		};

		_assessment.selectionMade = function (questionNumber) {

			var question = assessment.questions[questionNumber];

			switch (question.type) {
				case "SLIDER":
				case "FREE_TEXT":
				case "MULTI_OPTION_SINGLE_RESPONSE":
					return question.selectedValue !== null && question.selectedValue !== undefined && question.selectedValue !== "";
				case "MULTI_OPTION_MULTI_RESPONSE_NONE_AVAILABLE":
				case "MULTI_OPTION_MULTI_RESPONSE":
				default:
					return question.choices.some(function (choice) {
						return choice.selected;
					});

			}


		};

		_assessment.postResponse = function (responseObject) {

			var deferred = $q.defer();

			_assessment.getAssessmentLinks(responseObject['assessmentId']).then(function (links) {
					$http.post(links["patient-assessment-results"], responseObject)
						.success(function (response) {
							deferred.resolve(response);
						})
						.error(function (error) {
							deferred.reject(error)
						});
				},
				function (error) {
					deferred.reject(error);
				});

			return deferred.promise;
		};

		return assessment;

	});
});
