define(['angular', 'app', 'localResourceDirectoryService'], function (angular, app) {
	"use strict";
	app.service('NotificationsService', function (CollectionCRUDService, localResourceDirectoryService, pageService, formatter) {

		var NotificationsService = function(){
			var config = {}

			config.dependency = {
				service : localResourceDirectoryService,
				linkTitles : {
					GET : "preferences",
					POST : "preferences"
				}
			};

			config.collection = {
				objectType : "Notifications",
				name: "notifications",
				sortComparator : [{key: "dateSortKey", reverse: true}],
				filter: function (list, filters) {
					if(!filters.status || filters.status.toLowerCase() === "all") {
						return list;
					}

					var readStatus = filters.status.toLowerCase() === "read";

					return list.filter(function (item) {
						return item.readFlag === readStatus;
					});
				}
			};

			config.object = {
				uidKey : "_id",
				requestTransform : function(item) {
					item.effectiveDisplayDate = formatter.getFormattedBackendDateTime(item.effectiveDisplayDate);
					return item;
				},
				responseTransform : function(item) {
					item.stringUnreadIndicator = item.readFlag ? "Read Notification" : "Unread Notification";					

					var partialBodyArray = item.body.split(" ");

					item.partialBody = "";

					for(var i = 0; i < partialBodyArray.length && (item.partialBody.length + partialBodyArray[i].length <= 50); i++) {
						item.partialBody += " " + partialBodyArray[i];
					}

					if(!item.partialBody) {
						item.partialBody = item.body.substr(0, 50);
					}

					item.effectiveDate = formatter.getFormattedFrontendDate(item.effectiveDisplayDate);
					item.effectiveTime = formatter.getFormattedFrontendTime(item.effectiveDisplayDate);
					item.effectiveDisplayDate = item.effectiveDate + " " + item.effectiveTime;
					item.dateSortKey = new Date(item.effectiveDisplayDate);
					
					return item;
				}
			};

			CollectionCRUDService.call(this, config);
		};

		NotificationsService.prototype = Object.create(CollectionCRUDService.prototype);
		NotificationsService.prototype.constructor = NotificationsService;

		return NotificationsService;
	});
});