define(['angular', 'app', 'formatter', 'NotificationsService', 'PatientPreferenceService'], function (angular, app) {
	'use strict';

	app.controller('AssessmentNotificationController', function ($scope, $state, formatter, NotificationsService, PatientPreferenceService, focusService, $modalInstance) {
		$scope.$watch(function () {
			return $('div.modal-header h3').is(":visible");
		}, function (isVisible, wasVisible) {
			if (isVisible && !wasVisible) {
                focusService.focusElement($('div.modal-header h3'));
			}
		});

		var init = function () {
			$scope.notification = {};
			$scope.preferences = {};
			$scope.notification.triggerOptions = ['Never', 'One Week', 'One Month', 'Three Months'];
			new PatientPreferenceService.getPreferencesData().then(function (response){
				$scope.preferences.emailAddress = response.emailAddress;
				$scope.preferences.timeZone = response.timeZone;
				$scope.update = true;
			});
			new PatientPreferenceService.getNotificationsPreference().then(function (response){
				$scope.notificationPreferences = true;
			});
		};

		var calculateTriggerDate = function () {
			var date = new Date(),
				triggerDate,
				daysUntilTrigger;

			switch ($scope.notification.triggerChoice) {
				case 'Never':
					daysUntilTrigger = -1;
					break;
				case 'One Week':
					daysUntilTrigger = 7;
					break;
				case 'One Month':
					daysUntilTrigger = 30;
					break;
				case 'Three Months':
					daysUntilTrigger = 90;
					break;
			};
			$scope.daysUntilTrigger = daysUntilTrigger;
			triggerDate = new Date(date.setDate(date.getDate() + daysUntilTrigger));
			triggerDate = triggerDate.setHours(9, 0, 0, 0);
			return formatter.getFormattedBackendDateTime(triggerDate);
		};

		$scope.save = function () {
			if(this.assessmentNotificationForm.validationSummary.validate()){
				var item = {};
				item.effectiveDisplayDate = calculateTriggerDate();
				item.timeZone = $scope.preferences.timeZone;
				item.emailAddress = $scope.preferences.emailAddress;

				if($scope.update){
					PatientPreferenceService.updatePreferencesData(item.emailAddress, item.timeZone).then(function (response) {
						$modalInstance.close();
					});
				}
				else{
					(new NotificationsService()).save(item).then(function (response) {
						$modalInstance.close();
					});
				}
				var today = new Date();
				var eventDate = new Date(today);
				eventDate.setDate(today.getDate()+$scope.daysUntilTrigger);
				eventDate = eventDate.getMonth()+1+'/'+eventDate.getDate()+'/'+eventDate.getFullYear();
				var notification = {
					"title":"Care for caregivers reminder",
					"frequency": "Once",
					"alert": ["On the date"],
					"enabledFlag": true,
					"source": "Care for Care Givers",
					"eventDate": eventDate,
					"times": ["09:00 AM"],
					"notificationTypes": ["Email"],
					"auxData": [{
						"key": "source",
						"value": "CARE_FOR_CAREGIVER",
					},{  "key" : "emailSubject",
						"value": "Care for Caregivers assessment is due now"
					}
						,{  "key" : "emailSignature",
							"value": "Care for Caregivers"
						}
						,{  "key" : "emailBody",
							"value": "Care for Caregivers assessment is due now. "
						},{  "key" : "emailUpdateMessage",
							"value": "Please log into Care4Caregivers app to take assessment."
						}
					],
					"notificationStatus": "On"
				};
				if(!$scope.notificationPreferences){
					new PatientPreferenceService.createNotificationsPreference(true).then(function(response){
						console.log('created notification preference');
					});
				}
				if($scope.daysUntilTrigger > 0){
					new PatientPreferenceService.createNotification(notification).then(function(response){
						console.log('created notification');
					});
				}
			};
		};

		$scope.cancel = function () {
			$modalInstance.dismiss('cancel');
		};

		$scope.timeZoneOptions = [
			"(+00:00) WET (Western European Time)",
			"(+01:00) CET (Central European Time)",
			"(+02:00) EET (Eastern European Time)",
			"(+04:00) Europe/Moscow",
			"(+04:00) Asia/Dubai",
			"(+04:30) Asia/Kabul",
			"(+05:00) Asia/Aqtau",
			"(+05:00) Asia/Aqtobe",
			"(+05:45) Asia/Kathmandu",
			"(+06:00) Asia/Almaty",
			"(+06:30) Asia/Rangoon",
			"(+07:00) Asia/Bangkok",
			"(+07:00) Asia/Jakarta",
			"(+08:00) Asia/Singapore",
			"(+09:00) Asia/Jayapura",
			"(+09:00) Asia/Tokyo",
			"(+11:00) Asia/Sakhalin",
			"(+10:00) Australia/Sydney",
			"(+12:00) Asia/Anadyr",
			"(+12:00) Antarctica/McMurdo",
			"(+12:00) Pacific/Fiji",
			"(+13:00) Pacific/Enderbury",
			"(+14:00) Pacific/Kiritimati",
			"(-01:00) Atlantic/Cape_Verde",
			"(-01:00) America/Scoresbysund",
			"(-03:00) America/Argentina/San_Juan",
			"(-04:00) America/Argentina/San_Luis",
			"(-05:00) America/New_York (Eastern)",
			"(-06:00) America/Chicago (Central)",
			"(-07:00) America/Denver (Mountain)",
			"(-08:00) America/Los_Angeles (Pacific)",
			"(-09:00) America/Juneau",
			"(-10:00) Pacific/Honolulu",
			"(-11:00) Pacific/Midway",
			"(+00:00) Etc/GMT+12"
		];

		init();
	});
});