define([ 'angular', 'app', 'assessment_factory'], function (angular, app) {
	"use strict";
	app.controller('AssessmentController', function ($scope, $state, $stateParams, $timeout, $q, patient, assessment, modalService, focusService) {

		$stateParams.id = 'strain';
		$scope.isEligible = true;
		$q.all({assessmentData: assessment.initAsDraft($stateParams.id), patientData: patient.fetch()}).then(function (response) {
			var assessmentData = response.assessmentData,
				patientData = response.patientData;
			(function init() {

				$scope.$on('$viewContentLoaded', function (event) {
					focusService.focusPrimary();
				});
				focusService.focusPrimary();

				$scope.assessmentTitle = assessmentData.title;
				$scope.singlePageAssessment = false;
				$scope.questions = assessmentData.questions;
				$scope.introduction = {
					"prompt": "This 12-item assessment allows caregivers to self-assess their level of strain. The following screens display a series of statements about caregivers' experiences. Related to your experience over the past week, please provide a response to each statement by selecting either \"Never\", \"Rarely\", \"Sometimes\", \"Quite Frequently\", \"Nearly Always\". Caregivers are asked to complete this assessment monthly. The assessment is not designed to be taken more than once per week.",
					"display": true
				};
				$scope.totalQuestions = $scope.questions.length;

				$scope.currentQuestionNumber;

				var currentQuestionIndex = 0;

				$scope.questions.forEach(function (question, i) {
					if (question.selectionMade) {
						currentQuestionIndex = i;
					}
					switch (question.type) {
						case "SLIDER":
							question.inputType = "range";
							break;
						case "FREE_TEXT":
							question.inputType = "text";
							break;
						case "MULTI_OPTION_MULTI_RESPONSE_NONE_AVAILABLE":
						case "MULTI_OPTION_MULTI_RESPONSE":
							question.inputType = "checkbox";
							break;
						case "MULTI_OPTION_SINGLE_RESPONSE":
							question.inputType = "radio";
					}
				});

				$scope.currentQuestionNumber = currentQuestionIndex + 1;
				$scope.nextLabel = $scope.currentQuestionNumber === $scope.totalQuestions || $scope.singlePageAssessment ? "Submit" : "Next";
			})();

			var submit = function () {

				var modalContent = {
					closeButtonText: 'Return',
					actionButtonText: 'Continue',
					headerText: 'Submission Confirmation',
					bodyContentUrl: 'src/modules/assessments/pages/modal-content/submission-confirmation_content.html',
					data: {userName: patientData.firstName + " " + patientData.lastName,
						assessmentTitle: assessmentData.title}
				};

				modalService.showModal({}, modalContent).then(function () {
					assessment.submit().then(
						function (updatedAssessmentData) {
							$scope.assessmentForm.$setPristine();
							$state.go("main.auth.two-panel.secondary-navigation.assessment.preview", {'assessmentId': updatedAssessmentData.assessmentId, 'resultId': updatedAssessmentData.dataIdentifier.uniqueId});
						}
					);
				}, function () {
					$timeout(function () {
						document.querySelector(".questionnaire-next").focus();
					}, 600);
				});

			};


			$scope.navAction = function (action) {
				var edgeCase = false;
				switch (action) {
					case "NEXT":
						if ($scope.currentQuestionNumber === $scope.totalQuestions || $scope.singlePageAssessment) {
							edgeCase = true;
							submit();
						}
						break;
					case "BACK":
						if ($scope.currentQuestionNumber === 1 || $scope.singlePageAssessment) {
							edgeCase = true;
							$scope.introduction.display = true;
						}
						break;
				}
				;

				if (!edgeCase) {
					$scope.currentQuestionNumber = $scope.currentQuestionNumber + (action === 'NEXT' ? 1 : -1);
					$scope.nextLabel = $scope.currentQuestionNumber === $scope.totalQuestions ? "Submit" : "Next";
					document.querySelector("#question-number").focus();
				}

			};

			$scope.saveDraft = function () {
				assessment.saveDraft().then(function () {
					$scope.assessmentForm.$setPristine();
					// @todo Refactor
					modalService.showModal({}, {
						closeButtonText: 'OK',
						headerText: 'Confirmation',
						bodyText: 'Draft saved.',
					}).finally(function () {
						$timeout(function () {
							document.querySelector(".questionnaire-next").focus();
						}, 600);
					});

				});
			};
		}, function (error) {

			if(error.error == 'NOT ELIGIBLE'){
				$scope.isEligible = false;
				$scope.assessmentEligibilityMessage = error.rootResponse.message;

			}else{
				$state.go('^')
				focusService.focusSecondary();

			}

		});
	});
});

