define([
		'app',
		'eula_service',
		'resourcedirectory_service',
		'authentication_service',
		'mhpuser_service',
		'patient',
		'connection_error_service',
		'connection_timeout_service',
		'modalService',
		'EulaController',
		'HeaderController',
		'FooterController',
		'MainController',
		'HelpController',
		'AboutController',
		'accessibleDatePickerServices',
		'DateControls',
		'highcharts-ng',
		'SecondaryNavigationController',
		'HomeModule',
		'ManageModule',
		'SupportModule',
		'LearnModule',
		'AssessmentsModule',
		'FavoritesModule'
	],
	function (app) {
		"use strict";

		app.config(function ($stateProvider, unsavedWarningsConfigProvider) {

			$stateProvider
				.state('main', {
					abstract: true,
					data: {
						appletName: "Care4Caregivers",
						requiresAuth: false
					},
					views: {
						"": {
							templateUrl: 'src/container/main/main_template.html',
							controller: 'MainController'
						},
						'header@main': {
							templateUrl: 'src/container/components/header/header_template.html',
							controller: 'HeaderController'
						},
						'footer@main': {
							templateUrl: 'src/container/components/footer/footer_template.html',
							controller: 'FooterController'
						}
					},
					resolve: {
						token: function ($q, $location, authenticationService) {
							var defer = $q.defer(),
								currentUrl = $location.absUrl(),
								regExpr = new RegExp("[?&]token=" + authenticationService.getCurrentToken());

							!regExpr.test(currentUrl) ? defer.resolve() : defer.reject({ error: 'token', redirect: currentUrl.replace(regExpr, "")});
							return defer.promise;
						},
						eula: function ($q, eulaService) {
							var defer = $q.defer();
							eulaService.isAccepted() ? defer.resolve() : defer.reject({ error: 'eula' });
							return defer.promise;
						}
					}
				})
				.state('main.auth', {
					abstract: true,
					resolve: {
						auth: function ($q, $location, pageService, authenticationService, mhpuser) {
							var defer = $q.defer();
							authenticationService.checkAuthStatus().then(function (status) {
								if(status) {
									mhpuser.fetch().then(function (user) {
										pageService.isRoaAccepted(user) ? defer.resolve() : defer.reject({ error: 'roa', redirect: pageService.getROAUrl() });
									});
								} else {
									defer.reject({ error: 'auth' });
								}
								if(localStorage.getItem("c4c_router")){
									$location.path(localStorage.getItem("c4c_router"));
									if(location.hash == "#/"+localStorage.getItem('c4c_router')){
										localStorage.removeItem('c4c_router');
									}
								}
							});
							return defer.promise;
						}
					}
				})
				.state('main.auth.two-panel', {
					abstract: true,
					views: {
						'@main': {
							templateUrl: 'src/container/components/content/two-column_template.html',
							controller: 'TwoPanelController'
						}
					}
				})
				.state('main.auth.two-panel.secondary-navigation', {
					abstract: true,
					views : {
						'secondary@main.auth.two-panel' : {
							templateUrl: "src/container/components/content/secondary-navigation/secondary-navigation_template.html",
							controller: "SecondaryNavigationController"
						}
					}
				})
				.state('main.two-panel', {
					abstract: true,
					views: {
						'@main': {
							templateUrl: 'src/container/components/content/two-column_template.html',
							controller: 'TwoPanelController'
						}
					}
				})
				.state('main.two-panel.secondary-navigation', {
					abstract: true,
					views : {
						'secondary@main.two-panel' : {
							templateUrl: "src/container/components/content/secondary-navigation/secondary-navigation_template.html",
							controller: "SecondaryNavigationController"
						}
					}
				})
				.state('eula', {
					url: '/eula',
					data: {
						appletName: "Care4Caregivers",
						requiresAuth: false
					},
					templateUrl: 'src/core/eula/eula_template.html',
					controller: 'EulaController'
				})
				.state('nonStateRedirect', {
					url: '/redirecting'
				});

			unsavedWarningsConfigProvider.useTranslateService = false;
		});

		app.run(function ($rootScope, $state, $window, resourceDirectory, connectionErrorService, authenticationService) {
			connectionErrorService.run();
			resourceDirectory.fetch();

			$rootScope.$on('$stateChangeError', function (event, toState, toParams, fromState, fromParams, error) {

				if (error.redirect) {
					$state.go('nonStateRedirect');
					$window.open(error.redirect, '_self', null, true);
				} else {
					if (error.error === 'eula') {
						$state.go('eula');
					} else if (error.error === 'auth') {

						// if user tries to go to app option / nav option that requires auth, in those cases 
						// we want to directly send them to login page, rather than back to the unauthenticated splash page
						if (toState.name.indexOf('two-panel.secondary-navigation') > 0) {
							localStorage.setItem("c4c_router", toState.url.replace(/\//g,''));
							authenticationService.authenticate();
						} else {
							$state.go('main.unauthenticated-user');
						}
					}
				}
			});
		});
	});