define(['libs/angular/js/angular', 'app', 'formatter', 'NotificationsService', 'PatientPreferenceService'], function (angular, app) {
	'use strict';

	app.controller('AssessmentNotificationController', function ($scope, $state, formatter, NotificationsService, PatientPreferenceService, focusService) {
		$scope.$watch(function () {
			return $('div.modal-header h3').is(":visible");
		}, function (isVisible, wasVisible) {
			if (isVisible && !wasVisible) {
                focusService.focusElement($('div.modal-header h3'));
			}
		});

		var init = function () {
			$scope.notification = {};
			$scope.notification.triggerOptions = ['Never', 'One Week', 'One Month', 'Three Months'];
		};

		var calculateTriggerDate = function () {
			var date = new Date(),
				triggerDate,
				daysUntilTrigger;

			switch ($scope.notification.triggerChoice) {
				case 'Never':
					daysUntilTrigger = -1;
					break;
				case 'One Week':
					daysUntilTrigger = 7;
					break;
				case 'One Month':
					daysUntilTrigger = 30;
					break;
				case 'Three Months':
					daysUntilTrigger = 90;
					break;
			};

			triggerDate = new Date(date.setDate(date.getDate() + daysUntilTrigger));
			triggerDate = triggerDate.setHours(9, 0, 0, 0);
			return formatter.getFormattedBackendDateTime(triggerDate);
		};

		$scope.save = function () {
			this.assessmentNotificationForm.validationSummary.validate().then(function(){
				var item = {};
				item.source = 'My VA Health - ' + $state.current.data.appletName;
				item.body = 'Assessment' + ' is due now.';
				item.effectiveDisplayDate = calculateTriggerDate();
				item.type = "In-App";

				(new NotificationsService()).save(item).then(function (response) {
					//$modalInstance.close();
				});
			});
		};

		$scope.cancel = function () {
			//$modalInstance.dismiss('cancel');
		};

		$scope.timeZoneOptions = [
			"(+00:00) WET (Western European Time)",
			"(+01:00) CET (Central European Time)",
			"(+02:00) EET (Eastern European Time)",
			"(+04:00) Europe/Moscow",
			"(+04:00) Asia/Dubai",
			"(+04:30) Asia/Kabul",
			"(+05:00) Asia/Aqtau",
			"(+05:00) Asia/Aqtobe",
			"(+05:45) Asia/Kathmandu",
			"(+06:00) Asia/Almaty",
			"(+06:30) Asia/Rangoon",
			"(+07:00) Asia/Bangkok",
			"(+07:00) Asia/Jakarta",
			"(+08:00) Asia/Singapore",
			"(+09:00) Asia/Jayapura",
			"(+09:00) Asia/Tokyo",
			"(+11:00) Asia/Sakhalin",
			"(+10:00) Australia/Sydney",
			"(+12:00) Asia/Anadyr",
			"(+12:00) Antarctica/McMurdo",
			"(+12:00) Pacific/Fiji",
			"(+13:00) Pacific/Enderbury",
			"(+14:00) Pacific/Kiritimati",
			"(-01:00) Atlantic/Cape_Verde",
			"(-01:00) America/Scoresbysund",
			"(-03:00) America/Argentina/San_Juan",
			"(-04:00) America/Argentina/San_Luis",
			"(-05:00) America/New_York (Eastern)",
			"(-06:00) America/Chicago (Central)",
			"(-07:00) America/Denver (Mountain)",
			"(-08:00) America/Los_Angeles (Pacific)",
			"(-09:00) America/Juneau",
			"(-10:00) Pacific/Honolulu",
			"(-11:00) Pacific/Midway",
			"(+00:00) Etc/GMT+12"
		];

		init();
	});
});